package com.xingxi.master.merchant.mapper;

import com.xingxi.master.merchant.domain.Merchant;

import java.util.List;

/**
 * 商户Mapper接口
 *
 * @author xingxi
 * @date 2025-03-06
 */
public interface MerchantMapper {
    /**
     * 查询商户
     *
     * @param mercId 商户主键
     * @return 商户
     */
    Merchant selectMerchantByMercId(Long mercId);

    /**
     * 查询商户列表
     *
     * @param merchant 商户
     * @return 商户集合
     */
    List<Merchant> selectMerchantList(Merchant merchant);

    /**
     * 新增商户
     *
     * @param merchant 商户
     * @return 结果
     */
    int insertMerchant(Merchant merchant);

    /**
     * 批量新增商户
     *
     * @param merchantList 商户
     * @return 结果
     */
    int batchInsertMerchant(List<Merchant> merchantList);

    /**
     * 修改商户
     *
     * @param merchant 商户
     * @return 结果
     */
    int updateMerchant(Merchant merchant);

    /**
     * 删除商户
     *
     * @param mercId 商户主键
     * @return 结果
     */
    int deleteMerchantByMercId(Long mercId);

    /**
     * 批量删除商户
     *
     * @param mercIds 需要删除的数据主键集合
     * @return 结果
     */
    int deleteMerchantByMercIds(String[] mercIds);


    /**
     * 逻辑删除商户
     *
     * @param mercId 商户主键
     * @return 结果
     */
    int logicDeleteMerchantByMercId(Long mercId);

    /**
     * 逻辑批量删除商户
     *
     * @param mercIds 需要删除的数据主键集合
     * @return 结果
     */
    int logicDeleteMerchantByMercIds(String[] mercIds);

    /**
     * 逻辑批量删除商户
     *
     * @param merchant 商户
     * @return 结果
     */
    int logicDeleteMerchantByCondition(Merchant merchant);
}
